MCPcopy Create free account
hub / github.com/colmap/colmap / FillWithVectorKernel

Function FillWithVectorKernel

src/colmap/mvs/gpu_mat.h:361–369  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

359
360template <typename T>
361__global__ void FillWithVectorKernel(const T* values, GpuMatView<T> output) {
362 const size_t row = blockIdx.y * blockDim.y + threadIdx.y;
363 const size_t col = blockIdx.x * blockDim.x + threadIdx.x;
364 if (row < output.GetHeight() && col < output.GetWidth()) {
365 for (size_t slice = 0; slice < output.GetDepth(); ++slice) {
366 output.Set(row, col, slice, values[slice]);
367 }
368 }
369}
370
371template <typename T>
372__global__ void FillWithRandomNumbersKernel(

Callers

nothing calls this directly

Calls 4

GetHeightMethod · 0.45
GetWidthMethod · 0.45
GetDepthMethod · 0.45
SetMethod · 0.45

Tested by

no test coverage detected